/*------------------------------------------------------------------------------
						SEPIA
------------------------------------------------------------------------------*/

uniform float GreyPower <
	ui_type = "drag";
	ui_min = -1.0; ui_max = 1.0;
	ui_tooltip = "How much desaturate the image before tinting it.";
> = 0.00;

uniform float SepiaPower <
	ui_type = "drag";
	ui_min = -1.0; ui_max = 1.0;
	ui_tooltip = "How much to tint the image.";
> = 0.00;

uniform float3 ColorTone
<
	ui_type = "drag";
	ui_min = -10; ui_max = 10;
	ui_label = "RGB Balance";
	ui_tooltip = "What color to tint the image.";
> = float3(1.0, 1.0, 1.0);

#include "ReShade.fxh"

float4 SepiaPass( float4 colorInput, float2 Tex )
{
	float3 sepia = colorInput.rgb;
	
	// calculating amounts of input, grey and sepia colors to blend and combine
	float grey = dot(sepia, float3(0.2126, 0.7152, 0.0722));
	
	sepia *= ColorTone;
	
	float3 blend2 = (grey * GreyPower) + (colorInput.rgb / (GreyPower + 1));

	colorInput.rgb = lerp(blend2, sepia, SepiaPower);
	
	// returning the final color
	return colorInput;
}

float3 SepiaWrap(float4 position : SV_Position, float2 texcoord : TEXCOORD0) : SV_Target
{
	float4 color = tex2D(ReShade::BackBuffer, texcoord);

	color = SepiaPass(color,texcoord);

	return color.rgb;
}

technique Sepia_Tech
{
	pass
	{
		VertexShader = PostProcessVS;
		PixelShader = SepiaWrap;
	}
}